from grovepi import *
from grove_rgb_lcd import *
import time

# Grove Port Assignments
pir_port = 2         # D2
light_port = 1       # A0
button_port = 3      # D3

# Setup
pinMode(pir_port, "INPUT")
pinMode(button_port, "INPUT")

def self_check():
    status = {
        "PIR": False,
        "Light": False,
        "Button": False,
        "LCD": False
    }

    # Check LCD
    try:
        setText("Running self-\ncheck...")
        time.sleep(1)
        status["LCD"] = True
    except:
        print("[ERROR] LCD not responding.")

    # Check PIR
    try:
        motion = digitalRead(pir_port)
        print(f"[PASS] PIR motion sensor: {motion}")
        status["PIR"] = True
    except:
        print("[ERROR] PIR motion sensor not responding.")

    # Check Light Level
    try:
        light = analogRead(light_port)
        if 0 <= light <= 1023:
            print(f"[PASS] Light level sensor: {light}")
            status["Light"] = True
        else:
            print("[ERROR] Light sensor value out of range.")
    except:
        print("[ERROR] Light sensor not responding.")

    # Check Button
    try:
        state = digitalRead(button_port)
        print(f"[PASS] Button state: {'Pressed' if state == 0 else 'Released'}")
        status["Button"] = True
    except:
        print("[ERROR] Button not responding.")

    # Final Summary
    failed = [key for key, val in status.items() if not val]
    if not failed:
        setText("All systems\noperational.")
        print("[SUCCESS] All sensors passed.")
        return True
    else:
        setText("Self-check fail:\n" + ",".join(failed))
        print(f"[FAILED] Sensors failed: {', '.join(failed)}")
        return False

# Run test
if __name__ == "__main__":
    result = self_check()
    print("Self-check result:", "PASS" if result else "FAIL")
